@@ -2,8 +2,8 @@ __all__ = ['is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn',
            'canonical', 'get_canonical_isbn', 'editions']
 
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 
-from .isbntoolscore import is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,\
-    canonical, notisbn, get_isbnlike, get_canonical_isbn, mask, meta, info,\
-    editions
+from .core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
+    canonical, notisbn, get_isbnlike, get_canonical_isbn)
+from .ext import (mask, meta, info, editions)
